# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

Installation procedure: https://docs.microsoft.com/windows/wsl/install-win10
Troobleshooting installation: https://docs.microsoft.com/windows/wsl/troubleshooting
Kernel Installation procedure: https://aka.ms/wsl2kernel
WSL2: https://aka.ms/wsl2-install

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_name = "wsl_update_x64.msi"


def install():
    # Specific app values
    app_name = control.name

    # Installing the package
    if windows_version() >= WindowsVersions.Windows10v1709:
        with EnsureWUAUServRunning():
            print("Enabling Windows Feature: Microsoft-Windows-Subsystem-Linux")
            run_powershell("Enable-WindowsOptionalFeature -Online -FeatureName Microsoft-Windows-Subsystem-Linux -NoRestart -All")
            # Updating WSL to WSL2
            if windows_version() >= WindowsVersions.Windows10v2004:
                # Installing the Kernel WSL Update if needed
                install_msi_if_needed(bin_name)
                try:
                    print("Enabling Windows Feature: VirtualMachinePlatform")
                    run_powershell("Enable-WindowsOptionalFeature -Online -FeatureName VirtualMachinePlatform -NoRestart -All")
                except:
                    print("Unable to install %s, please reboot and make sure that virtualization is enabled in the BIOS" % app_name)
                try:
                    print("Configuring %s as default" % app_name)
                    run_powershell("wsl --set-default-version 2")
                except:
                    print("Unable to configure %s as default" % app_name)
            else:
                print("You need Windows 10 version 2004 minimum for installing %s" % app_name)
    else:
        print("You need Windows 10 version 1709 minimum for installing WSL")

    print("INFO: A reboot is required to use %s" % app_name)


def uninstall():
    # Uninstalling the package
    if windows_version() >= WindowsVersions.Windows10v1709:
        with EnsureWUAUServRunning():
            print("Disabling Windows Feature: Microsoft-Windows-Subsystem-Linux")
            run_powershell("Disable-WindowsOptionalFeature -Online -FeatureName Microsoft-Windows-Subsystem-Linux -NoRestart")
            if windows_version() >= "10.0.19041":
                print("Disabling Windows Feature: VirtualMachinePlatform")
                run_powershell("Disable-WindowsOptionalFeature -Online -FeatureName VirtualMachinePlatform -NoRestart")
